==> qmmp_0.4.1.orig.tar.gz: qmmp-0.4.1/src/plugins/Output/oss/translations/oss_plugin_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE">
<context>
    <name>OutputOSSFactory</name>
    <message>
        <location filename="../outputossfactory.cpp" line="36"/>
        <source>OSS Plugin</source>
        <translation>OSS-Modul</translation>
    </message>
    <message>
        <location filename="../outputossfactory.cpp" line="56"/>
        <source>About OSS Output Plugin</source>
        <translation>Über OSS-Ausgabe-Modul</translation>
    </message>
    <message>
        <location filename="../outputossfactory.cpp" line="57"/>
        <source>Qmmp OSS Output Plugin</source>
        <translation>Qmmp OSS-Ausgabe-Modul</translation>
    </message>
    <message>
        <location filename="../outputossfactory.cpp" line="58"/>
        <source>Writen by: Yuriy Zhuravlev &lt;slalkerg@gmail.com&gt;</source>
        <translation>Autor: Yuriy Zhuravlev &lt;slalkerg@gmail.com&gt;</translation>
    </message>
    <message>
        <location filename="../outputossfactory.cpp" line="59"/>
        <source>Based on code by: Brad Hughes &lt;bhughes@trolltech.com&gt;</source>
        <translation>Basiert auf Quellcode von: Brad Hughes &lt;bhughes@trolltech.com&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>OSS Plugin Settings</source>
        <translation>Einstellungen OSS-Modul</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="30"/>
        <source>Device Settings</source>
        <translation>Geräte-Einstellungen</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="42"/>
        <source>Audio device</source>
        <translation>Audiogerät</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="58"/>
        <source>Mixer device</source>
        <translation>Mixergerät</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="81"/>
        <source>Advanced Settings</source>
        <translation>Erweiterte Einstellungen</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="93"/>
        <source>Soundcard</source>
        <translation>Soundkarte</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="157"/>
        <source>Buffer time (ms):</source>
        <translation>Pufferzeit (ms):</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="167"/>
        <source>Period time (ms):</source>
        <translation>Zeitraster (ms):</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="197"/>
        <source>PCM over Master</source>
        <translation>PCM over Master</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="224"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="231"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
</TS>

==> qmmp_0.5.2.orig.tar.gz: qmmp-0.5.2/src/plugins/Output/oss/translations/oss_plugin_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE">
<context>
    <name>OutputOSSFactory</name>
    <message>
        <location filename="../outputossfactory.cpp" line="36"/>
        <source>OSS Plugin</source>
        <translation>OSS-Modul</translation>
    </message>
    <message>
        <location filename="../outputossfactory.cpp" line="56"/>
        <source>About OSS Output Plugin</source>
        <translation>Über OSS-Ausgabe-Modul</translation>
    </message>
    <message>
        <location filename="../outputossfactory.cpp" line="57"/>
        <source>Qmmp OSS Output Plugin</source>
        <translation>Qmmp OSS-Ausgabe-Modul</translation>
    </message>
    <message>
        <location filename="../outputossfactory.cpp" line="58"/>
        <source>Written by: Yuriy Zhuravlev &lt;slalkerg@gmail.com&gt;</source>
        <translation>Autor: Yuriy Zhuravlev &lt;slalkerg@gmail.com&gt;</translation>
    </message>
    <message>
        <location filename="../outputossfactory.cpp" line="59"/>
        <source>Based on code by: Brad Hughes &lt;bhughes@trolltech.com&gt;</source>
        <translation>Basiert auf Quellcode von: Brad Hughes &lt;bhughes@trolltech.com&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>OSS Plugin Settings</source>
        <translation>Einstellungen OSS-Modul</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="30"/>
        <source>Device Settings</source>
        <translation>Geräte-Einstellungen</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="42"/>
        <source>Audio device</source>
        <translation>Audiogerät</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="58"/>
        <source>Mixer device</source>
        <translation>Mixergerät</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="81"/>
        <source>Advanced Settings</source>
        <translation>Erweiterte Einstellungen</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="93"/>
        <source>Soundcard</source>
        <translation>Soundkarte</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="157"/>
        <source>Buffer time (ms):</source>
        <translation>Pufferzeit (ms):</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="167"/>
        <source>Period time (ms):</source>
        <translation>Zeitraster (ms):</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="197"/>
        <source>PCM over Master</source>
        <translation>PCM over Master</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="224"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="231"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
</TS>
